@@ -45,18 +45,19 @@
 void theme_init( GTypeModule* module )
 {
 
+    #if OXYGEN_DEBUG
+    std::cerr << "Oxygen::theme_init" << std::endl;
+    #endif
+
     Oxygen::RCStyle::registerType( module );
     Oxygen::StyleWrapper::registerType( module );
 
-    // disable all animations for openoffice
-    if(
-        Oxygen::Style::instance().settings().applicationName().isOpenOffice() )
-    {
-        Oxygen::Style::instance().animations().setEnabled( false );
-        Oxygen::Style::instance().animations().setInnerShadowsEnabled( false );
-        // re-enable combobox animations
-        Oxygen::Style::instance().animations().comboBoxEngine().setEnabled( true );
-    }
+    // initialize oxygen here, for XUL applications
+    // special care is taken to not initialize everything
+    Oxygen::ApplicationName applicationName;
+    applicationName.initialize();
+    if( applicationName.isXul() )
+    { Oxygen::Style::instance().initialize( Oxygen::QtSettings::Forced | Oxygen::QtSettings::Colors ); }
 
 }
 
@@ -127,7 +128,4 @@ gint getWindecoButtonSize(unsigned long buttonType)
 
 //_________________________________________________
 unsigned long getWindecoABIVersion(void)
-{
-    return 0x3;
-}
-
+{ return 0x3; }
